@@ -5,12 +5,12 @@ use Geo::GoogleEarth::Pluggable;
 
 =head1 NAME
 
-Geo-GoogleEarth-Pluggable-Folders_with_Points.pl - Geo-GoogleEarth-Pluggable Example with Folders and Points
+Geo-GoogleEarth-Pluggable-Folders_with_Points.pl - Geo-GoogleEarth-Pluggable Folders and Points Example
 
 =cut
 
 my $document=Geo::GoogleEarth::Pluggable->new(name=>"My Document");
-foreach my $f (3..5) {
+foreach my $f (3,4,5,6) {
   my $folder=$document->Folder(name=>"My Folder $f", description=>"F$f Desc");
   my $point=$folder->Point(name=>"My Point $f", lat=>"39.$f", lon=>"-77.$f"); 
 }
